@@ -24,6 +24,7 @@
 #include <sys/ioctl.h>
 #include <hildon/hildon.h>
 
+int lw,lh;
 static GdkImage *image;
 #ifndef DIABLO
 static HildonAnimationActor *actor;
@@ -324,6 +325,12 @@ gtk_widget_queue_draw (drawing);
 	while (gtk_events_pending())
 		gtk_main_iteration();
 
+#ifdef DIABLO
+	GdkPixbuf *pixbuf,*dest = gtk_image_get_pixbuf(GDK_IMAGE(image));
+	dest = gdk_pixbuf_scale_simple(pixbuf, lw, lh, GDK_INTERP_NEAREST);
+	gtk_image_set_from_pixbuf(GTK_IMAGE(drawing), dest);
+#endif
+		
 	return pl_vout_buf;
 	
 }
@@ -335,7 +342,8 @@ void fb_wait_vsync(void)
 
 void fb_set_mode(int w, int h, int buffers, int scale, int filter)
 {
-  int lx, ly, lw = w, lh = h;
+  int lx, ly;
+  lw = w, lh = h;
   switch (scale) {
     case 0:
       lw = w;
@@ -353,6 +361,10 @@ void fb_set_mode(int w, int h, int buffers, int scale, int filter)
       lw = 800;
       lh = 480;
       break;
+	case 15:
+		lw=800;
+		lh=480;
+		break;
     default:
       fprintf(stderr, "unknown scale: %d\n", scale);
       break;
@@ -370,13 +382,11 @@ void fb_set_mode(int w, int h, int buffers, int scale, int filter)
 
 	pl_vout_buf = (void *) image->mem;
 
-	gtk_image_set_from_image (GTK_IMAGE(drawing), image, NULL);
+
 #ifdef DIABLO
-	GdkPixbuf *pixbuf =	gtk_image_get_pixbuf(GDK_IMAGE(image));
 	gtk_window_resize (GTK_WINDOW (drawing), lw, lh);
-	pixbuf = gdk_pixbuf_scale_simple(pixbuf, drawing->allocation.width, drawing->allocation.height, 1);
-	gtk_image_set_from_pixbuf(GTK_IMAGE(drawing), pixbuf);
 #else
+	gtk_image_set_from_image (GTK_IMAGE(drawing), image, NULL);
 	gtk_window_resize (GTK_WINDOW (actor), w, h);
 	hildon_animation_actor_set_position (actor, lx, ly );
 	hildon_animation_actor_set_scale (actor,(gdouble)lw/ (gdouble)w,(gdouble)lh / (gdouble)h);
